@@ -11,7 +11,7 @@ package Kernel::System::Console::Command::Maint::Session::ListAll;
 use strict;
 use warnings;
 
-use base qw(Kernel::System::Console::BaseCommand);
+use parent qw(Kernel::System::Console::BaseCommand);
 
 our @ObjectDependencies = (
     'Kernel::System::AuthSession',
